#[non_exhaustive]pub struct RejectAssignmentInput {
pub assignment_id: Option<String>,
pub requester_feedback: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.assignment_id: Option<String>The ID of the assignment. The assignment must correspond to a HIT created by the Requester.
requester_feedback: Option<String>A message for the Worker, which the Worker can see in the Status section of the web site.
Implementations
Sourceimpl RejectAssignmentInput
impl RejectAssignmentInput
Sourcepub fn assignment_id(&self) -> Option<&str>
pub fn assignment_id(&self) -> Option<&str>
The ID of the assignment. The assignment must correspond to a HIT created by the Requester.
Sourcepub fn requester_feedback(&self) -> Option<&str>
pub fn requester_feedback(&self) -> Option<&str>
A message for the Worker, which the Worker can see in the Status section of the web site.
Sourceimpl RejectAssignmentInput
impl RejectAssignmentInput
Sourcepub fn builder() -> RejectAssignmentInputBuilder
pub fn builder() -> RejectAssignmentInputBuilder
Creates a new builder-style object to manufacture RejectAssignmentInput.