#[non_exhaustive]pub struct HitLayoutParameter {
pub name: String,
pub value: String,
}Expand description
The HITLayoutParameter data structure defines parameter values used with a HITLayout. A HITLayout is a reusable Amazon Mechanical Turk project template used to provide Human Intelligence Task (HIT) question data for CreateHIT.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the parameter in the HITLayout.
value: StringThe value substituted for the parameter referenced in the HITLayout.
Implementations
Sourceimpl HitLayoutParameter
impl HitLayoutParameter
Sourcepub fn builder() -> HitLayoutParameterBuilder
pub fn builder() -> HitLayoutParameterBuilder
Creates a new builder-style object to manufacture HitLayoutParameter.