#[non_exhaustive]pub struct NotificationSpecification {
pub destination: String,
pub transport: NotificationTransport,
pub version: String,
pub event_types: Vec<EventType>,
}Expand description
The NotificationSpecification data structure describes a HIT event notification for a HIT type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: StringThe target for notification messages. The Destination’s format is determined by the specified Transport:
-
When Transport is Email, the Destination is your email address.
-
When Transport is SQS, the Destination is your queue URL.
-
When Transport is SNS, the Destination is the ARN of your topic.
transport: NotificationTransportThe method Amazon Mechanical Turk uses to send the notification. Valid Values: Email | SQS | SNS.
version: StringThe version of the Notification API to use. Valid value is 2006-05-05.
event_types: Vec<EventType>The list of events that should cause notifications to be sent. Valid Values: AssignmentAccepted | AssignmentAbandoned | AssignmentReturned | AssignmentSubmitted | AssignmentRejected | AssignmentApproved | HITCreated | HITExtended | HITDisposed | HITReviewable | HITExpired | Ping. The Ping event is only valid for the SendTestEventNotification operation.
Implementations
Sourceimpl NotificationSpecification
impl NotificationSpecification
Sourcepub fn destination(&self) -> &str
pub fn destination(&self) -> &str
The target for notification messages. The Destination’s format is determined by the specified Transport:
-
When Transport is Email, the Destination is your email address.
-
When Transport is SQS, the Destination is your queue URL.
-
When Transport is SNS, the Destination is the ARN of your topic.
Sourcepub fn transport(&self) -> &NotificationTransport
pub fn transport(&self) -> &NotificationTransport
The method Amazon Mechanical Turk uses to send the notification. Valid Values: Email | SQS | SNS.
Sourcepub fn version(&self) -> &str
pub fn version(&self) -> &str
The version of the Notification API to use. Valid value is 2006-05-05.
Sourcepub fn event_types(&self) -> &[EventType]
pub fn event_types(&self) -> &[EventType]
The list of events that should cause notifications to be sent. Valid Values: AssignmentAccepted | AssignmentAbandoned | AssignmentReturned | AssignmentSubmitted | AssignmentRejected | AssignmentApproved | HITCreated | HITExtended | HITDisposed | HITReviewable | HITExpired | Ping. The Ping event is only valid for the SendTestEventNotification operation.
Sourceimpl NotificationSpecification
impl NotificationSpecification
Sourcepub fn builder() -> NotificationSpecificationBuilder
pub fn builder() -> NotificationSpecificationBuilder
Creates a new builder-style object to manufacture NotificationSpecification.